@@ -5,8 +5,6 @@ __all__ = [
 import os
 import sys
 import argparse
-from Gaugi import Logger
-from Gaugi.messenger.macros import *
 import requests
 from hashlib import sha256, md5
 import pickle
@@ -15,10 +13,9 @@ from pathlib import Path
 from lps_maestro.utils import getCredentialsData
 from lps_maestro.constants import *
 
-class Authenticate (Logger):
+class Authenticate ():
 
   def __init__(self):
-    Logger.__init__(self)
     self.__class__ = type(self.__class__.__name__, (self.__class__,), {})
     self.__class__.__call__ = self.authenticate
 
@@ -28,20 +25,20 @@ class Authenticate (Logger):
     return m.hexdigest()
 
   def authenticate (self, username, password):
-    MSG_INFO (self, "Trying to connect...")
+    print ("Trying to connect...")
     data = {
       'username':username,
       'password':password
     }
     try:
       r = requests.post(url='http://146.164.147.170:5020/authenticate', data=data)
-      MSG_INFO (self, r.text)
+      print (r.text)
       if (r.json()['error_code'] == 200):
         home = str(Path.home())
         f = open("{}/{}".format(home, CREDENTIALS_FILE), "wb+")
         f.write("${}${}".format(username, r.json()['token']).encode('utf-8'))
         f.close()
     except requests.exceptions.ConnectionError:
-      MSG_ERROR (self, "Failed to connect to LPS Cluster.")
+      print ("Failed to connect to LPS Cluster.")
 
 authenticate = Authenticate()
\ No newline at end of file
